# data-repo-client
<details><summary>This document defines the REST API for the Terra Data Repository.</summary> <p> **Status: design in progress**
There are a few top-level endpoints (besides some used by swagger):
 * / - generated by swagger: swagger API page that provides this
documentation and a live UI for submitting REST requests
 * /status - provides the operational status of the service
 * /configuration - provides the basic configuration and information about the service
 * /api - is the authenticated and authorized Data Repository API
 * /ga4gh/drs/v1 - is a transcription of the Data Repository Service API

The API endpoints are organized by interface. Each interface is separately versioned. <p> **Notes on Naming** <p> All of the reference items are suffixed with \\\"Model\\\". Those names are used as the class names in the generated Java code. It is helpful to distinguish these model classes from other related classes, like the DAO classes and the operation classes. </details>


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.1.0
- Package version: 1.483.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python &gt;&#x3D;3.7

## Migration from other generators like python and python-legacy

### Changes
1. This generator uses spec case for all (object) property names and parameter names.
    - So if the spec has a property name like camelCase, it will use camelCase rather than camel_case
    - So you will need to update how you input and read properties to use spec case
2. Endpoint parameters are stored in dictionaries to prevent collisions (explanation below)
    - So you will need to update how you pass data in to endpoints
3. Endpoint responses now include the original response, the deserialized response body, and (todo)the deserialized headers
    - So you will need to update your code to use response.body to access deserialized data
4. All validated data is instantiated in an instance that subclasses all validated Schema classes and Decimal/str/list/tuple/frozendict/NoneClass/BoolClass/bytes/io.FileIO
    - This means that you can use isinstance to check if a payload validated against a schema class
    - This means that no data will be of type None/True/False
        - ingested None will subclass NoneClass
        - ingested True will subclass BoolClass
        - ingested False will subclass BoolClass
        - So if you need to check is True/False/None, instead use instance.is_true_oapg()/.is_false_oapg()/.is_none_oapg()
5. All validated class instances are immutable except for ones based on io.File
    - This is because if properties were changed after validation, that validation would no longer apply
    - So no changing values or property values after a class has been instantiated
6. String + Number types with formats
    - String type data is stored as a string and if you need to access types based on its format like date,
    date-time, uuid, number etc then you will need to use accessor functions on the instance
    - type string + format: See .as_date_oapg, .as_datetime_oapg, .as_decimal_oapg, .as_uuid_oapg
    - type number + format: See .as_float_oapg, .as_int_oapg
    - this was done because openapi/json-schema defines constraints. string data may be type string with no format
    keyword in one schema, and include a format constraint in another schema
    - So if you need to access a string format based type, use as_date_oapg/as_datetime_oapg/as_decimal_oapg/as_uuid_oapg
    - So if you need to access a number format based type, use as_int_oapg/as_float_oapg
7. Property access on AnyType(type unset) or object(dict) schemas
    - Only required keys with valid python names are properties like .someProp and have type hints
    - All optional keys may not exist, so properties are not defined for them
    - One can access optional values with dict_instance['optionalProp'] and KeyError will be raised if it does not exist
    - Use get_item_oapg if you need a way to always get a value whether or not the key exists
        - If the key does not exist, schemas.unset is returned from calling dict_instance.get_item_oapg('optionalProp')
        - All required and optional keys have type hints for this method, and @typing.overload is used
        - A type hint is also generated for additionalProperties accessed using this method
    - So you will need to update you code to use some_instance['optionalProp'] to access optional property
    and additionalProperty values
8. The location of the api classes has changed
    - Api classes are located in your_package.apis.tags.some_api
    - This change was made to eliminate redundant code generation
    - Legacy generators generated the same endpoint twice if it had > 1 tag on it
    - This generator defines an endpoint in one class, then inherits that class to generate
      apis by tags and by paths
    - This change reduces code and allows quicker run time if you use the path apis
        - path apis are at your_package.apis.paths.some_path
    - Those apis will only load their needed models, which is less to load than all of the resources needed in a tag api
    - So you will need to update your import paths to the api classes

### Why are Oapg and _oapg used in class and method names?
Classes can have arbitrarily named properties set on them
Endpoints can have arbitrary operationId method names set
For those reasons, I use the prefix Oapg and _oapg to greatly reduce the likelihood of collisions
on protected + public classes/methods.
oapg stands for OpenApi Python Generator.

### Object property spec case
This was done because when payloads are ingested, they can be validated against N number of schemas.
If the input signature used a different property name then that has mutated the payload.
So SchemaA and SchemaB must both see the camelCase spec named variable.
Also it is possible to send in two properties, named camelCase and camel_case in the same payload.
That use case should be support so spec case is used.

### Parameter spec case
Parameters can be included in different locations including:
- query
- path
- header
- cookie

Any of those parameters could use the same parameter names, so if every parameter
was included as an endpoint parameter in a function signature, they would collide.
For that reason, each of those inputs have been separated out into separate typed dictionaries:
- query_params
- path_params
- header_params
- cookie_params

So when updating your code, you will need to pass endpoint parameters in using those
dictionaries.

### Endpoint responses
Endpoint responses have been enriched to now include more information.
Any response reom an endpoint will now include the following properties:
response: urllib3.HTTPResponse
body: typing.Union[Unset, Schema]
headers: typing.Union[Unset, TODO]
Note: response header deserialization has not yet been added


## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import data_repo_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import data_repo_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import data_repo_client
from pprint import pprint
from data_repo_client.apis.tags import data_repository_service_api
from data_repo_client.model.drs_access_url import DRSAccessURL
from data_repo_client.model.drs_authorizations import DRSAuthorizations
from data_repo_client.model.drs_error import DRSError
from data_repo_client.model.drs_object import DRSObject
from data_repo_client.model.drs_passport_request_model import DRSPassportRequestModel
from data_repo_client.model.drs_service_info import DRSServiceInfo
# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = data_repo_client.Configuration(
    host = "http://localhost"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure OAuth2 access token for authorization: googleoauth
configuration = data_repo_client.Configuration(
    host = "http://localhost",
    access_token = 'YOUR_ACCESS_TOKEN'
)

# Configure OAuth2 access token for authorization: oidc
configuration = data_repo_client.Configuration(
    host = "http://localhost",
    access_token = 'YOUR_ACCESS_TOKEN'
)

# Enter a context with an instance of the API client
with data_repo_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = data_repository_service_api.DataRepositoryServiceApi(api_client)
    object_id = "object_id_example" # str | An `id` of a Data Object
access_id = "access_id_example" # str | An `access_id` from the `access_methods` list of a Data Object

    try:
        # Get a URL for fetching bytes.
        api_response = api_instance.get_access_url(object_idaccess_id)
        pprint(api_response)
    except data_repo_client.ApiException as e:
        print("Exception when calling DataRepositoryServiceApi->get_access_url: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DataRepositoryServiceApi* | [**get_access_url**](docs/apis/tags/DataRepositoryServiceApi.md#get_access_url) | **get** /ga4gh/drs/v1/objects/{object_id}/access/{access_id} | Get a URL for fetching bytes.
*DataRepositoryServiceApi* | [**get_object**](docs/apis/tags/DataRepositoryServiceApi.md#get_object) | **get** /ga4gh/drs/v1/objects/{object_id} | Get info about an &#x60;Object&#x60;.
*DataRepositoryServiceApi* | [**get_service_info**](docs/apis/tags/DataRepositoryServiceApi.md#get_service_info) | **get** /ga4gh/drs/v1/service-info | Get information about this implementation.
*DataRepositoryServiceApi* | [**options_object**](docs/apis/tags/DataRepositoryServiceApi.md#options_object) | **options** /ga4gh/drs/v1/objects/{object_id} | Get Authorization info about a DRS Object.
*DataRepositoryServiceApi* | [**post_access_url**](docs/apis/tags/DataRepositoryServiceApi.md#post_access_url) | **post** /ga4gh/drs/v1/objects/{object_id}/access/{access_id} | Get a URL for fetching bytes through POST&#x27;ing a Passport
*DataRepositoryServiceApi* | [**post_object**](docs/apis/tags/DataRepositoryServiceApi.md#post_object) | **post** /ga4gh/drs/v1/objects/{object_id} | Get info about a DrsObject through POST&#x27;ing a Passport.
*ConfigsApi* | [**get_config**](docs/apis/tags/ConfigsApi.md#get_config) | **get** /api/repository/v1/configs/{name} | 
*ConfigsApi* | [**get_config_list**](docs/apis/tags/ConfigsApi.md#get_config_list) | **get** /api/repository/v1/configs | 
*ConfigsApi* | [**reset_config**](docs/apis/tags/ConfigsApi.md#reset_config) | **put** /api/repository/v1/configs/reset | 
*ConfigsApi* | [**set_config_list**](docs/apis/tags/ConfigsApi.md#set_config_list) | **put** /api/repository/v1/configs | 
*ConfigsApi* | [**set_fault**](docs/apis/tags/ConfigsApi.md#set_fault) | **put** /api/repository/v1/configs/{name} | 
*DatasetsApi* | [**add_dataset_asset_specifications**](docs/apis/tags/DatasetsApi.md#add_dataset_asset_specifications) | **post** /api/repository/v1/datasets/{id}/assets | 
*DatasetsApi* | [**add_dataset_policy_member**](docs/apis/tags/DatasetsApi.md#add_dataset_policy_member) | **post** /api/repository/v1/datasets/{id}/policies/{policyName}/members | 
*DatasetsApi* | [**apply_dataset_data_deletion**](docs/apis/tags/DatasetsApi.md#apply_dataset_data_deletion) | **post** /api/repository/v1/datasets/{id}/deletes | 
*DatasetsApi* | [**bulk_file_load**](docs/apis/tags/DatasetsApi.md#bulk_file_load) | **post** /api/repository/v1/datasets/{id}/files/bulk | 
*DatasetsApi* | [**bulk_file_load_array**](docs/apis/tags/DatasetsApi.md#bulk_file_load_array) | **post** /api/repository/v1/datasets/{id}/files/bulk/array | 
*DatasetsApi* | [**bulk_file_results_delete**](docs/apis/tags/DatasetsApi.md#bulk_file_results_delete) | **delete** /api/repository/v1/datasets/{id}/files/bulk/{loadTag} | 
*DatasetsApi* | [**close_transaction**](docs/apis/tags/DatasetsApi.md#close_transaction) | **post** /api/repository/v1/datasets/{id}/transactions/{transactionId} | 
*DatasetsApi* | [**create_dataset**](docs/apis/tags/DatasetsApi.md#create_dataset) | **post** /api/repository/v1/datasets | 
*DatasetsApi* | [**delete_dataset**](docs/apis/tags/DatasetsApi.md#delete_dataset) | **delete** /api/repository/v1/datasets/{id} | 
*DatasetsApi* | [**delete_dataset_policy_member**](docs/apis/tags/DatasetsApi.md#delete_dataset_policy_member) | **delete** /api/repository/v1/datasets/{id}/policies/{policyName}/members/{memberEmail} | 
*DatasetsApi* | [**delete_file**](docs/apis/tags/DatasetsApi.md#delete_file) | **delete** /api/repository/v1/datasets/{id}/files/{fileid} | 
*DatasetsApi* | [**enumerate_datasets**](docs/apis/tags/DatasetsApi.md#enumerate_datasets) | **get** /api/repository/v1/datasets | 
*DatasetsApi* | [**enumerate_transactions**](docs/apis/tags/DatasetsApi.md#enumerate_transactions) | **get** /api/repository/v1/datasets/{id}/transactions | 
*DatasetsApi* | [**get_dataset_tags**](docs/apis/tags/DatasetsApi.md#get_dataset_tags) | **get** /api/repository/v1/datasets/tags | 
*DatasetsApi* | [**get_load_history_for_load_tag**](docs/apis/tags/DatasetsApi.md#get_load_history_for_load_tag) | **get** /api/repository/v1/datasets/{id}/files/bulk/{loadTag} | 
*DatasetsApi* | [**ingest_dataset**](docs/apis/tags/DatasetsApi.md#ingest_dataset) | **post** /api/repository/v1/datasets/{id}/ingest | 
*DatasetsApi* | [**ingest_file**](docs/apis/tags/DatasetsApi.md#ingest_file) | **post** /api/repository/v1/datasets/{id}/files | 
*DatasetsApi* | [**lookup_dataset_data_by_id**](docs/apis/tags/DatasetsApi.md#lookup_dataset_data_by_id) | **get** /api/repository/v1/datasets/{id}/data/{table} | 
*DatasetsApi* | [**lookup_file_by_id**](docs/apis/tags/DatasetsApi.md#lookup_file_by_id) | **get** /api/repository/v1/datasets/{id}/files/{fileid} | 
*DatasetsApi* | [**lookup_file_by_path**](docs/apis/tags/DatasetsApi.md#lookup_file_by_path) | **get** /api/repository/v1/datasets/{id}/filesystem/objects | 
*DatasetsApi* | [**open_transaction**](docs/apis/tags/DatasetsApi.md#open_transaction) | **post** /api/repository/v1/datasets/{id}/transactions | 
*DatasetsApi* | [**patch_dataset**](docs/apis/tags/DatasetsApi.md#patch_dataset) | **patch** /api/repository/v1/datasets/{id} | 
*DatasetsApi* | [**remove_dataset_asset_specifications**](docs/apis/tags/DatasetsApi.md#remove_dataset_asset_specifications) | **delete** /api/repository/v1/datasets/{id}/assets/{assetid} | 
*DatasetsApi* | [**retrieve_dataset**](docs/apis/tags/DatasetsApi.md#retrieve_dataset) | **get** /api/repository/v1/datasets/{id} | 
*DatasetsApi* | [**retrieve_dataset_policies**](docs/apis/tags/DatasetsApi.md#retrieve_dataset_policies) | **get** /api/repository/v1/datasets/{id}/policies | 
*DatasetsApi* | [**retrieve_dataset_summary**](docs/apis/tags/DatasetsApi.md#retrieve_dataset_summary) | **get** /api/repository/v1/datasets/{id}/summary | 
*DatasetsApi* | [**retrieve_transaction**](docs/apis/tags/DatasetsApi.md#retrieve_transaction) | **get** /api/repository/v1/datasets/{id}/transactions/{transactionId} | 
*DatasetsApi* | [**retrieve_user_dataset_roles**](docs/apis/tags/DatasetsApi.md#retrieve_user_dataset_roles) | **get** /api/repository/v1/datasets/{id}/roles | 
*DatasetsApi* | [**update_dataset_tags**](docs/apis/tags/DatasetsApi.md#update_dataset_tags) | **patch** /api/repository/v1/datasets/{id}/tags | 
*DatasetsApi* | [**update_schema**](docs/apis/tags/DatasetsApi.md#update_schema) | **post** /api/repository/v1/datasets/{id}/updateSchema | 
*DuosApi* | [**retrieve_duos_firecloud_group**](docs/apis/tags/DuosApi.md#retrieve_duos_firecloud_group) | **get** /api/repository/v1/duos/{duosId} | 
*DuosApi* | [**retrieve_duos_firecloud_groups**](docs/apis/tags/DuosApi.md#retrieve_duos_firecloud_groups) | **get** /api/repository/v1/duos | 
*DuosApi* | [**sync_duos_dataset_authorized_users**](docs/apis/tags/DuosApi.md#sync_duos_dataset_authorized_users) | **put** /api/repository/v1/duos/{duosId}/syncAuthorizedUsers | 
*DuosApi* | [**sync_duos_datasets_authorized_users**](docs/apis/tags/DuosApi.md#sync_duos_datasets_authorized_users) | **put** /api/repository/v1/duos/syncAuthorizedUsers | 
*JobsApi* | [**enumerate_jobs**](docs/apis/tags/JobsApi.md#enumerate_jobs) | **get** /api/repository/v1/jobs | 
*JobsApi* | [**retrieve_job**](docs/apis/tags/JobsApi.md#retrieve_job) | **get** /api/repository/v1/jobs/{id} | 
*JobsApi* | [**retrieve_job_result**](docs/apis/tags/JobsApi.md#retrieve_job_result) | **get** /api/repository/v1/jobs/{id}/result | 
*JournalApi* | [**retrieve_journal_entries**](docs/apis/tags/JournalApi.md#retrieve_journal_entries) | **get** /api/repository/v1/journal/{resourceKey} | 
*ProfilesApi* | [**add_profile_policy_member**](docs/apis/tags/ProfilesApi.md#add_profile_policy_member) | **post** /api/resources/v1/profiles/{id}/policies/{policyName}/members | 
*ProfilesApi* | [**create_profile**](docs/apis/tags/ProfilesApi.md#create_profile) | **post** /api/resources/v1/profiles | 
*ProfilesApi* | [**delete_profile**](docs/apis/tags/ProfilesApi.md#delete_profile) | **delete** /api/resources/v1/profiles/{id} | 
*ProfilesApi* | [**delete_profile_policy_member**](docs/apis/tags/ProfilesApi.md#delete_profile_policy_member) | **delete** /api/resources/v1/profiles/{id}/policies/{policyName}/members/{memberEmail} | 
*ProfilesApi* | [**enumerate_profiles**](docs/apis/tags/ProfilesApi.md#enumerate_profiles) | **get** /api/resources/v1/profiles | 
*ProfilesApi* | [**retrieve_profile**](docs/apis/tags/ProfilesApi.md#retrieve_profile) | **get** /api/resources/v1/profiles/{id} | 
*ProfilesApi* | [**retrieve_profile_policies**](docs/apis/tags/ProfilesApi.md#retrieve_profile_policies) | **get** /api/resources/v1/profiles/{id}/policies | 
*ProfilesApi* | [**update_profile**](docs/apis/tags/ProfilesApi.md#update_profile) | **put** /api/resources/v1/profiles | 
*RegisterApi* | [**user**](docs/apis/tags/RegisterApi.md#user) | **get** /api/repository/v1/register/user | 
*RepositoryApi* | [**add_dataset_asset_specifications**](docs/apis/tags/RepositoryApi.md#add_dataset_asset_specifications) | **post** /api/repository/v1/datasets/{id}/assets | 
*RepositoryApi* | [**add_dataset_policy_member**](docs/apis/tags/RepositoryApi.md#add_dataset_policy_member) | **post** /api/repository/v1/datasets/{id}/policies/{policyName}/members | 
*RepositoryApi* | [**add_snapshot_policy_member**](docs/apis/tags/RepositoryApi.md#add_snapshot_policy_member) | **post** /api/repository/v1/snapshots/{id}/policies/{policyName}/members | 
*RepositoryApi* | [**apply_dataset_data_deletion**](docs/apis/tags/RepositoryApi.md#apply_dataset_data_deletion) | **post** /api/repository/v1/datasets/{id}/deletes | 
*RepositoryApi* | [**bulk_file_load**](docs/apis/tags/RepositoryApi.md#bulk_file_load) | **post** /api/repository/v1/datasets/{id}/files/bulk | 
*RepositoryApi* | [**bulk_file_load_array**](docs/apis/tags/RepositoryApi.md#bulk_file_load_array) | **post** /api/repository/v1/datasets/{id}/files/bulk/array | 
*RepositoryApi* | [**bulk_file_results_delete**](docs/apis/tags/RepositoryApi.md#bulk_file_results_delete) | **delete** /api/repository/v1/datasets/{id}/files/bulk/{loadTag} | 
*RepositoryApi* | [**close_transaction**](docs/apis/tags/RepositoryApi.md#close_transaction) | **post** /api/repository/v1/datasets/{id}/transactions/{transactionId} | 
*RepositoryApi* | [**create_dataset**](docs/apis/tags/RepositoryApi.md#create_dataset) | **post** /api/repository/v1/datasets | 
*RepositoryApi* | [**create_search_index**](docs/apis/tags/RepositoryApi.md#create_search_index) | **post** /api/repository/v1/search/{id}/index | 
*RepositoryApi* | [**create_snapshot**](docs/apis/tags/RepositoryApi.md#create_snapshot) | **post** /api/repository/v1/snapshots | 
*RepositoryApi* | [**delete_dataset**](docs/apis/tags/RepositoryApi.md#delete_dataset) | **delete** /api/repository/v1/datasets/{id} | 
*RepositoryApi* | [**delete_dataset_policy_member**](docs/apis/tags/RepositoryApi.md#delete_dataset_policy_member) | **delete** /api/repository/v1/datasets/{id}/policies/{policyName}/members/{memberEmail} | 
*RepositoryApi* | [**delete_file**](docs/apis/tags/RepositoryApi.md#delete_file) | **delete** /api/repository/v1/datasets/{id}/files/{fileid} | 
*RepositoryApi* | [**delete_snapshot**](docs/apis/tags/RepositoryApi.md#delete_snapshot) | **delete** /api/repository/v1/snapshots/{id} | 
*RepositoryApi* | [**delete_snapshot_policy_member**](docs/apis/tags/RepositoryApi.md#delete_snapshot_policy_member) | **delete** /api/repository/v1/snapshots/{id}/policies/{policyName}/members/{memberEmail} | 
*RepositoryApi* | [**enumerate_datasets**](docs/apis/tags/RepositoryApi.md#enumerate_datasets) | **get** /api/repository/v1/datasets | 
*RepositoryApi* | [**enumerate_jobs**](docs/apis/tags/RepositoryApi.md#enumerate_jobs) | **get** /api/repository/v1/jobs | 
*RepositoryApi* | [**enumerate_snapshots**](docs/apis/tags/RepositoryApi.md#enumerate_snapshots) | **get** /api/repository/v1/snapshots | 
*RepositoryApi* | [**enumerate_transactions**](docs/apis/tags/RepositoryApi.md#enumerate_transactions) | **get** /api/repository/v1/datasets/{id}/transactions | 
*RepositoryApi* | [**export_snapshot**](docs/apis/tags/RepositoryApi.md#export_snapshot) | **get** /api/repository/v1/snapshots/{id}/export | 
*RepositoryApi* | [**get_config**](docs/apis/tags/RepositoryApi.md#get_config) | **get** /api/repository/v1/configs/{name} | 
*RepositoryApi* | [**get_config_list**](docs/apis/tags/RepositoryApi.md#get_config_list) | **get** /api/repository/v1/configs | 
*RepositoryApi* | [**get_dataset_tags**](docs/apis/tags/RepositoryApi.md#get_dataset_tags) | **get** /api/repository/v1/datasets/tags | 
*RepositoryApi* | [**get_load_history_for_load_tag**](docs/apis/tags/RepositoryApi.md#get_load_history_for_load_tag) | **get** /api/repository/v1/datasets/{id}/files/bulk/{loadTag} | 
*RepositoryApi* | [**get_snapshot_ids_and_roles**](docs/apis/tags/RepositoryApi.md#get_snapshot_ids_and_roles) | **get** /api/repository/v1/snapshots/roleMap | 
*RepositoryApi* | [**get_snapshot_tags**](docs/apis/tags/RepositoryApi.md#get_snapshot_tags) | **get** /api/repository/v1/snapshots/tags | 
*RepositoryApi* | [**ingest_dataset**](docs/apis/tags/RepositoryApi.md#ingest_dataset) | **post** /api/repository/v1/datasets/{id}/ingest | 
*RepositoryApi* | [**ingest_file**](docs/apis/tags/RepositoryApi.md#ingest_file) | **post** /api/repository/v1/datasets/{id}/files | 
*RepositoryApi* | [**link_duos_dataset_to_snapshot**](docs/apis/tags/RepositoryApi.md#link_duos_dataset_to_snapshot) | **put** /api/repository/v1/snapshots/{id}/linkDuosDataset/{duosId} | 
*RepositoryApi* | [**lookup_dataset_data_by_id**](docs/apis/tags/RepositoryApi.md#lookup_dataset_data_by_id) | **get** /api/repository/v1/datasets/{id}/data/{table} | 
*RepositoryApi* | [**lookup_file_by_id**](docs/apis/tags/RepositoryApi.md#lookup_file_by_id) | **get** /api/repository/v1/datasets/{id}/files/{fileid} | 
*RepositoryApi* | [**lookup_file_by_path**](docs/apis/tags/RepositoryApi.md#lookup_file_by_path) | **get** /api/repository/v1/datasets/{id}/filesystem/objects | 
*RepositoryApi* | [**lookup_snapshot_file_by_id**](docs/apis/tags/RepositoryApi.md#lookup_snapshot_file_by_id) | **get** /api/repository/v1/snapshots/{id}/files/{fileid} | 
*RepositoryApi* | [**lookup_snapshot_file_by_path**](docs/apis/tags/RepositoryApi.md#lookup_snapshot_file_by_path) | **get** /api/repository/v1/snapshots/{id}/filesystem/objects | 
*RepositoryApi* | [**lookup_snapshot_preview_by_id**](docs/apis/tags/RepositoryApi.md#lookup_snapshot_preview_by_id) | **get** /api/repository/v1/snapshots/{id}/data/{table} | 
*RepositoryApi* | [**open_transaction**](docs/apis/tags/RepositoryApi.md#open_transaction) | **post** /api/repository/v1/datasets/{id}/transactions | 
*RepositoryApi* | [**patch_dataset**](docs/apis/tags/RepositoryApi.md#patch_dataset) | **patch** /api/repository/v1/datasets/{id} | 
*RepositoryApi* | [**patch_snapshot**](docs/apis/tags/RepositoryApi.md#patch_snapshot) | **patch** /api/repository/v1/snapshots/{id} | 
*RepositoryApi* | [**query_search_indices**](docs/apis/tags/RepositoryApi.md#query_search_indices) | **post** /api/repository/v1/search/query | 
*RepositoryApi* | [**remove_dataset_asset_specifications**](docs/apis/tags/RepositoryApi.md#remove_dataset_asset_specifications) | **delete** /api/repository/v1/datasets/{id}/assets/{assetid} | 
*RepositoryApi* | [**reset_config**](docs/apis/tags/RepositoryApi.md#reset_config) | **put** /api/repository/v1/configs/reset | 
*RepositoryApi* | [**retrieve_dataset**](docs/apis/tags/RepositoryApi.md#retrieve_dataset) | **get** /api/repository/v1/datasets/{id} | 
*RepositoryApi* | [**retrieve_dataset_policies**](docs/apis/tags/RepositoryApi.md#retrieve_dataset_policies) | **get** /api/repository/v1/datasets/{id}/policies | 
*RepositoryApi* | [**retrieve_dataset_summary**](docs/apis/tags/RepositoryApi.md#retrieve_dataset_summary) | **get** /api/repository/v1/datasets/{id}/summary | 
*RepositoryApi* | [**retrieve_duos_firecloud_group**](docs/apis/tags/RepositoryApi.md#retrieve_duos_firecloud_group) | **get** /api/repository/v1/duos/{duosId} | 
*RepositoryApi* | [**retrieve_duos_firecloud_groups**](docs/apis/tags/RepositoryApi.md#retrieve_duos_firecloud_groups) | **get** /api/repository/v1/duos | 
*RepositoryApi* | [**retrieve_job**](docs/apis/tags/RepositoryApi.md#retrieve_job) | **get** /api/repository/v1/jobs/{id} | 
*RepositoryApi* | [**retrieve_job_result**](docs/apis/tags/RepositoryApi.md#retrieve_job_result) | **get** /api/repository/v1/jobs/{id}/result | 
*RepositoryApi* | [**retrieve_snapshot**](docs/apis/tags/RepositoryApi.md#retrieve_snapshot) | **get** /api/repository/v1/snapshots/{id} | 
*RepositoryApi* | [**retrieve_snapshot_policies**](docs/apis/tags/RepositoryApi.md#retrieve_snapshot_policies) | **get** /api/repository/v1/snapshots/{id}/policies | 
*RepositoryApi* | [**retrieve_snapshot_summary**](docs/apis/tags/RepositoryApi.md#retrieve_snapshot_summary) | **get** /api/repository/v1/snapshots/{id}/summary | 
*RepositoryApi* | [**retrieve_transaction**](docs/apis/tags/RepositoryApi.md#retrieve_transaction) | **get** /api/repository/v1/datasets/{id}/transactions/{transactionId} | 
*RepositoryApi* | [**retrieve_user_dataset_roles**](docs/apis/tags/RepositoryApi.md#retrieve_user_dataset_roles) | **get** /api/repository/v1/datasets/{id}/roles | 
*RepositoryApi* | [**retrieve_user_snapshot_roles**](docs/apis/tags/RepositoryApi.md#retrieve_user_snapshot_roles) | **get** /api/repository/v1/snapshots/{id}/roles | 
*RepositoryApi* | [**set_config_list**](docs/apis/tags/RepositoryApi.md#set_config_list) | **put** /api/repository/v1/configs | 
*RepositoryApi* | [**set_fault**](docs/apis/tags/RepositoryApi.md#set_fault) | **put** /api/repository/v1/configs/{name} | 
*RepositoryApi* | [**sync_duos_dataset_authorized_users**](docs/apis/tags/RepositoryApi.md#sync_duos_dataset_authorized_users) | **put** /api/repository/v1/duos/{duosId}/syncAuthorizedUsers | 
*RepositoryApi* | [**sync_duos_datasets_authorized_users**](docs/apis/tags/RepositoryApi.md#sync_duos_datasets_authorized_users) | **put** /api/repository/v1/duos/syncAuthorizedUsers | 
*RepositoryApi* | [**unlink_duos_dataset_from_snapshot**](docs/apis/tags/RepositoryApi.md#unlink_duos_dataset_from_snapshot) | **delete** /api/repository/v1/snapshots/{id}/unlinkDuosDataset | 
*RepositoryApi* | [**update_dataset_tags**](docs/apis/tags/RepositoryApi.md#update_dataset_tags) | **patch** /api/repository/v1/datasets/{id}/tags | 
*RepositoryApi* | [**update_schema**](docs/apis/tags/RepositoryApi.md#update_schema) | **post** /api/repository/v1/datasets/{id}/updateSchema | 
*RepositoryApi* | [**update_snapshot_tags**](docs/apis/tags/RepositoryApi.md#update_snapshot_tags) | **patch** /api/repository/v1/snapshots/{id}/tags | 
*RepositoryApi* | [**upgrade**](docs/apis/tags/RepositoryApi.md#upgrade) | **post** /api/repository/v1/upgrade | 
*RepositoryApi* | [**user**](docs/apis/tags/RepositoryApi.md#user) | **get** /api/repository/v1/register/user | 
*ResourcesApi* | [**add_profile_policy_member**](docs/apis/tags/ResourcesApi.md#add_profile_policy_member) | **post** /api/resources/v1/profiles/{id}/policies/{policyName}/members | 
*ResourcesApi* | [**create_profile**](docs/apis/tags/ResourcesApi.md#create_profile) | **post** /api/resources/v1/profiles | 
*ResourcesApi* | [**delete_profile**](docs/apis/tags/ResourcesApi.md#delete_profile) | **delete** /api/resources/v1/profiles/{id} | 
*ResourcesApi* | [**delete_profile_policy_member**](docs/apis/tags/ResourcesApi.md#delete_profile_policy_member) | **delete** /api/resources/v1/profiles/{id}/policies/{policyName}/members/{memberEmail} | 
*ResourcesApi* | [**enumerate_profiles**](docs/apis/tags/ResourcesApi.md#enumerate_profiles) | **get** /api/resources/v1/profiles | 
*ResourcesApi* | [**retrieve_profile**](docs/apis/tags/ResourcesApi.md#retrieve_profile) | **get** /api/resources/v1/profiles/{id} | 
*ResourcesApi* | [**retrieve_profile_policies**](docs/apis/tags/ResourcesApi.md#retrieve_profile_policies) | **get** /api/resources/v1/profiles/{id}/policies | 
*ResourcesApi* | [**update_profile**](docs/apis/tags/ResourcesApi.md#update_profile) | **put** /api/resources/v1/profiles | 
*SearchApi* | [**create_search_index**](docs/apis/tags/SearchApi.md#create_search_index) | **post** /api/repository/v1/search/{id}/index | 
*SearchApi* | [**lookup_dataset_data_by_id**](docs/apis/tags/SearchApi.md#lookup_dataset_data_by_id) | **get** /api/repository/v1/datasets/{id}/data/{table} | 
*SearchApi* | [**lookup_snapshot_preview_by_id**](docs/apis/tags/SearchApi.md#lookup_snapshot_preview_by_id) | **get** /api/repository/v1/snapshots/{id}/data/{table} | 
*SearchApi* | [**query_search_indices**](docs/apis/tags/SearchApi.md#query_search_indices) | **post** /api/repository/v1/search/query | 
*SnapshotsApi* | [**add_snapshot_policy_member**](docs/apis/tags/SnapshotsApi.md#add_snapshot_policy_member) | **post** /api/repository/v1/snapshots/{id}/policies/{policyName}/members | 
*SnapshotsApi* | [**create_search_index**](docs/apis/tags/SnapshotsApi.md#create_search_index) | **post** /api/repository/v1/search/{id}/index | 
*SnapshotsApi* | [**create_snapshot**](docs/apis/tags/SnapshotsApi.md#create_snapshot) | **post** /api/repository/v1/snapshots | 
*SnapshotsApi* | [**delete_snapshot**](docs/apis/tags/SnapshotsApi.md#delete_snapshot) | **delete** /api/repository/v1/snapshots/{id} | 
*SnapshotsApi* | [**delete_snapshot_policy_member**](docs/apis/tags/SnapshotsApi.md#delete_snapshot_policy_member) | **delete** /api/repository/v1/snapshots/{id}/policies/{policyName}/members/{memberEmail} | 
*SnapshotsApi* | [**enumerate_snapshots**](docs/apis/tags/SnapshotsApi.md#enumerate_snapshots) | **get** /api/repository/v1/snapshots | 
*SnapshotsApi* | [**export_snapshot**](docs/apis/tags/SnapshotsApi.md#export_snapshot) | **get** /api/repository/v1/snapshots/{id}/export | 
*SnapshotsApi* | [**get_snapshot_ids_and_roles**](docs/apis/tags/SnapshotsApi.md#get_snapshot_ids_and_roles) | **get** /api/repository/v1/snapshots/roleMap | 
*SnapshotsApi* | [**get_snapshot_tags**](docs/apis/tags/SnapshotsApi.md#get_snapshot_tags) | **get** /api/repository/v1/snapshots/tags | 
*SnapshotsApi* | [**link_duos_dataset_to_snapshot**](docs/apis/tags/SnapshotsApi.md#link_duos_dataset_to_snapshot) | **put** /api/repository/v1/snapshots/{id}/linkDuosDataset/{duosId} | 
*SnapshotsApi* | [**lookup_snapshot_file_by_id**](docs/apis/tags/SnapshotsApi.md#lookup_snapshot_file_by_id) | **get** /api/repository/v1/snapshots/{id}/files/{fileid} | 
*SnapshotsApi* | [**lookup_snapshot_file_by_path**](docs/apis/tags/SnapshotsApi.md#lookup_snapshot_file_by_path) | **get** /api/repository/v1/snapshots/{id}/filesystem/objects | 
*SnapshotsApi* | [**lookup_snapshot_preview_by_id**](docs/apis/tags/SnapshotsApi.md#lookup_snapshot_preview_by_id) | **get** /api/repository/v1/snapshots/{id}/data/{table} | 
*SnapshotsApi* | [**patch_snapshot**](docs/apis/tags/SnapshotsApi.md#patch_snapshot) | **patch** /api/repository/v1/snapshots/{id} | 
*SnapshotsApi* | [**query_search_indices**](docs/apis/tags/SnapshotsApi.md#query_search_indices) | **post** /api/repository/v1/search/query | 
*SnapshotsApi* | [**retrieve_snapshot**](docs/apis/tags/SnapshotsApi.md#retrieve_snapshot) | **get** /api/repository/v1/snapshots/{id} | 
*SnapshotsApi* | [**retrieve_snapshot_policies**](docs/apis/tags/SnapshotsApi.md#retrieve_snapshot_policies) | **get** /api/repository/v1/snapshots/{id}/policies | 
*SnapshotsApi* | [**retrieve_snapshot_summary**](docs/apis/tags/SnapshotsApi.md#retrieve_snapshot_summary) | **get** /api/repository/v1/snapshots/{id}/summary | 
*SnapshotsApi* | [**retrieve_user_snapshot_roles**](docs/apis/tags/SnapshotsApi.md#retrieve_user_snapshot_roles) | **get** /api/repository/v1/snapshots/{id}/roles | 
*SnapshotsApi* | [**unlink_duos_dataset_from_snapshot**](docs/apis/tags/SnapshotsApi.md#unlink_duos_dataset_from_snapshot) | **delete** /api/repository/v1/snapshots/{id}/unlinkDuosDataset | 
*SnapshotsApi* | [**update_snapshot_tags**](docs/apis/tags/SnapshotsApi.md#update_snapshot_tags) | **patch** /api/repository/v1/snapshots/{id}/tags | 
*UnauthenticatedApi* | [**retrieve_repository_config**](docs/apis/tags/UnauthenticatedApi.md#retrieve_repository_config) | **get** /configuration | 
*UnauthenticatedApi* | [**service_status**](docs/apis/tags/UnauthenticatedApi.md#service_status) | **get** /status | 
*UnauthenticatedApi* | [**shutdown_request**](docs/apis/tags/UnauthenticatedApi.md#shutdown_request) | **get** /shutdown | 
*UpgradeApi* | [**upgrade**](docs/apis/tags/UpgradeApi.md#upgrade) | **post** /api/repository/v1/upgrade | 

## Documentation For Models

 - [AccessInfoBigQueryModel](docs/models/AccessInfoBigQueryModel.md)
 - [AccessInfoBigQueryModelTable](docs/models/AccessInfoBigQueryModelTable.md)
 - [AccessInfoModel](docs/models/AccessInfoModel.md)
 - [AccessInfoParquetModel](docs/models/AccessInfoParquetModel.md)
 - [AccessInfoParquetModelTable](docs/models/AccessInfoParquetModelTable.md)
 - [AssetModel](docs/models/AssetModel.md)
 - [AssetTableModel](docs/models/AssetTableModel.md)
 - [BillingProfileModel](docs/models/BillingProfileModel.md)
 - [BillingProfileRequestModel](docs/models/BillingProfileRequestModel.md)
 - [BillingProfileUpdateModel](docs/models/BillingProfileUpdateModel.md)
 - [BulkLoadArrayRequestModel](docs/models/BulkLoadArrayRequestModel.md)
 - [BulkLoadArrayResultModel](docs/models/BulkLoadArrayResultModel.md)
 - [BulkLoadFileModel](docs/models/BulkLoadFileModel.md)
 - [BulkLoadFileResultModel](docs/models/BulkLoadFileResultModel.md)
 - [BulkLoadFileState](docs/models/BulkLoadFileState.md)
 - [BulkLoadHistoryModel](docs/models/BulkLoadHistoryModel.md)
 - [BulkLoadHistoryModelList](docs/models/BulkLoadHistoryModelList.md)
 - [BulkLoadRequestModel](docs/models/BulkLoadRequestModel.md)
 - [BulkLoadResultModel](docs/models/BulkLoadResultModel.md)
 - [CloudPlatform](docs/models/CloudPlatform.md)
 - [ColumnModel](docs/models/ColumnModel.md)
 - [ColumnNameProperty](docs/models/ColumnNameProperty.md)
 - [CompactIdPrefix](docs/models/CompactIdPrefix.md)
 - [ConfigEnableModel](docs/models/ConfigEnableModel.md)
 - [ConfigFaultCountedModel](docs/models/ConfigFaultCountedModel.md)
 - [ConfigFaultModel](docs/models/ConfigFaultModel.md)
 - [ConfigGroupModel](docs/models/ConfigGroupModel.md)
 - [ConfigListModel](docs/models/ConfigListModel.md)
 - [ConfigModel](docs/models/ConfigModel.md)
 - [ConfigParameterModel](docs/models/ConfigParameterModel.md)
 - [ConsentCode](docs/models/ConsentCode.md)
 - [DRSAccessMethod](docs/models/DRSAccessMethod.md)
 - [DRSAccessURL](docs/models/DRSAccessURL.md)
 - [DRSAuthorizations](docs/models/DRSAuthorizations.md)
 - [DRSChecksum](docs/models/DRSChecksum.md)
 - [DRSContentsObject](docs/models/DRSContentsObject.md)
 - [DRSError](docs/models/DRSError.md)
 - [DRSObject](docs/models/DRSObject.md)
 - [DRSPassportRequestModel](docs/models/DRSPassportRequestModel.md)
 - [DRSServiceInfo](docs/models/DRSServiceInfo.md)
 - [DataDeletionGcsFileModel](docs/models/DataDeletionGcsFileModel.md)
 - [DataDeletionJsonArrayModel](docs/models/DataDeletionJsonArrayModel.md)
 - [DataDeletionRequest](docs/models/DataDeletionRequest.md)
 - [DataDeletionTableModel](docs/models/DataDeletionTableModel.md)
 - [DatasetDataModel](docs/models/DatasetDataModel.md)
 - [DatasetModel](docs/models/DatasetModel.md)
 - [DatasetPatchRequestModel](docs/models/DatasetPatchRequestModel.md)
 - [DatasetRequestAccessIncludeModel](docs/models/DatasetRequestAccessIncludeModel.md)
 - [DatasetRequestModel](docs/models/DatasetRequestModel.md)
 - [DatasetSchemaColumnUpdateModel](docs/models/DatasetSchemaColumnUpdateModel.md)
 - [DatasetSchemaUpdateModel](docs/models/DatasetSchemaUpdateModel.md)
 - [DatasetSnapshotNameProperty](docs/models/DatasetSnapshotNameProperty.md)
 - [DatasetSpecificationModel](docs/models/DatasetSpecificationModel.md)
 - [DatasetSummaryModel](docs/models/DatasetSummaryModel.md)
 - [DatePartitionOptionsModel](docs/models/DatePartitionOptionsModel.md)
 - [DeleteResponseModel](docs/models/DeleteResponseModel.md)
 - [DirectoryDetailModel](docs/models/DirectoryDetailModel.md)
 - [DuosFirecloudGroupModel](docs/models/DuosFirecloudGroupModel.md)
 - [DuosFirecloudGroupsSyncResponse](docs/models/DuosFirecloudGroupsSyncResponse.md)
 - [DuosId](docs/models/DuosId.md)
 - [EnumerateBillingProfileModel](docs/models/EnumerateBillingProfileModel.md)
 - [EnumerateDatasetModel](docs/models/EnumerateDatasetModel.md)
 - [EnumerateSnapshotModel](docs/models/EnumerateSnapshotModel.md)
 - [EnumerateSortByParam](docs/models/EnumerateSortByParam.md)
 - [ErrorModel](docs/models/ErrorModel.md)
 - [FileDetailModel](docs/models/FileDetailModel.md)
 - [FileLoadModel](docs/models/FileLoadModel.md)
 - [FileModel](docs/models/FileModel.md)
 - [FileModelType](docs/models/FileModelType.md)
 - [IamResourceTypeEnum](docs/models/IamResourceTypeEnum.md)
 - [InaccessibleWorkspacePolicyModel](docs/models/InaccessibleWorkspacePolicyModel.md)
 - [IngestRequestModel](docs/models/IngestRequestModel.md)
 - [IngestResponseModel](docs/models/IngestResponseModel.md)
 - [IntPartitionOptionsModel](docs/models/IntPartitionOptionsModel.md)
 - [JobModel](docs/models/JobModel.md)
 - [JournalEntryModel](docs/models/JournalEntryModel.md)
 - [LoadTagModel](docs/models/LoadTagModel.md)
 - [Md5OverrideModel](docs/models/Md5OverrideModel.md)
 - [ObjectNameProperty](docs/models/ObjectNameProperty.md)
 - [PhsId](docs/models/PhsId.md)
 - [PolicyMemberRequest](docs/models/PolicyMemberRequest.md)
 - [PolicyModel](docs/models/PolicyModel.md)
 - [PolicyResponse](docs/models/PolicyResponse.md)
 - [RelationshipModel](docs/models/RelationshipModel.md)
 - [RelationshipTermModel](docs/models/RelationshipTermModel.md)
 - [RepositoryConfigurationModel](docs/models/RepositoryConfigurationModel.md)
 - [RepositoryStatusModel](docs/models/RepositoryStatusModel.md)
 - [ResourceCreateTags](docs/models/ResourceCreateTags.md)
 - [ResourcePolicyModel](docs/models/ResourcePolicyModel.md)
 - [SamPolicyModel](docs/models/SamPolicyModel.md)
 - [SearchIndexModel](docs/models/SearchIndexModel.md)
 - [SearchIndexRequest](docs/models/SearchIndexRequest.md)
 - [SearchMetadataModel](docs/models/SearchMetadataModel.md)
 - [SearchMetadataResponse](docs/models/SearchMetadataResponse.md)
 - [SearchQueryRequest](docs/models/SearchQueryRequest.md)
 - [SearchQueryResultModel](docs/models/SearchQueryResultModel.md)
 - [ShortIdProperty](docs/models/ShortIdProperty.md)
 - [SnapshotExportResponseModel](docs/models/SnapshotExportResponseModel.md)
 - [SnapshotIdsAndRolesModel](docs/models/SnapshotIdsAndRolesModel.md)
 - [SnapshotLinkDuosDatasetResponse](docs/models/SnapshotLinkDuosDatasetResponse.md)
 - [SnapshotModel](docs/models/SnapshotModel.md)
 - [SnapshotPatchRequestModel](docs/models/SnapshotPatchRequestModel.md)
 - [SnapshotPreviewModel](docs/models/SnapshotPreviewModel.md)
 - [SnapshotRequestAssetModel](docs/models/SnapshotRequestAssetModel.md)
 - [SnapshotRequestContentsModel](docs/models/SnapshotRequestContentsModel.md)
 - [SnapshotRequestModel](docs/models/SnapshotRequestModel.md)
 - [SnapshotRequestQueryModel](docs/models/SnapshotRequestQueryModel.md)
 - [SnapshotRequestRowIdModel](docs/models/SnapshotRequestRowIdModel.md)
 - [SnapshotRequestRowIdTableModel](docs/models/SnapshotRequestRowIdTableModel.md)
 - [SnapshotRetrieveIncludeModel](docs/models/SnapshotRetrieveIncludeModel.md)
 - [SnapshotSourceModel](docs/models/SnapshotSourceModel.md)
 - [SnapshotSummaryModel](docs/models/SnapshotSummaryModel.md)
 - [SqlSortDirection](docs/models/SqlSortDirection.md)
 - [StorageResourceModel](docs/models/StorageResourceModel.md)
 - [TableDataType](docs/models/TableDataType.md)
 - [TableModel](docs/models/TableModel.md)
 - [Tag](docs/models/Tag.md)
 - [TagCount](docs/models/TagCount.md)
 - [TagCountResultModel](docs/models/TagCountResultModel.md)
 - [TagUpdateRequestModel](docs/models/TagUpdateRequestModel.md)
 - [TransactionCloseModel](docs/models/TransactionCloseModel.md)
 - [TransactionCreateModel](docs/models/TransactionCreateModel.md)
 - [TransactionModel](docs/models/TransactionModel.md)
 - [UniqueIdProperty](docs/models/UniqueIdProperty.md)
 - [UpgradeModel](docs/models/UpgradeModel.md)
 - [UpgradeResponseModel](docs/models/UpgradeResponseModel.md)
 - [UserStatusInfo](docs/models/UserStatusInfo.md)
 - [WorkspacePolicyModel](docs/models/WorkspacePolicyModel.md)

## Documentation For Authorization

Authentication schemes defined for the API:
<a id="googleoauth"></a>
### googleoauth

- **Type**: OAuth
- **Flow**: implicit
- **Authorization URL**: https://accounts.google.com/o/oauth2/auth
- **Scopes**: 
 - **openid**: open id authorization
 - **email**: email authorization
 - **profile**: profile authorization
 - **https://www.googleapis.com/auth/cloud-billing.readonly**: cloud billing authorization

<a id="oidc"></a>
### oidc

- **Type**: OAuth
- **Flow**: accessCode
- **Authorization URL**: /oauth2/authorize
- **Scopes**: 
 - **openid**: open id authorization
 - **email**: email authorization
 - **profile**: profile authorization


## Author
















## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in data_repo_client.apis and data_repo_client.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from data_repo_client.apis.default_api import DefaultApi`
- `from data_repo_client.model.pet import Pet`

Solution 1:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import data_repo_client
from data_repo_client.apis import *
from data_repo_client.models import *
```
